==> nextcloud-27.0.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/text/l10n/id.js <==
OC.L10N.register(
    "text",
    {
    "New text file" : "Berkas teks baru",
    "The file was uploaded" : "Berkas terunggah",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Berkas terunggah melampau parameter upload_max_filesize pada php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Berkas yang diunggah melampaui direktif MAX_FILE_SIZE yang ditentukan dalam formulir HTML.",
    "The file was only partially uploaded" : "Berkas hanya sebagian terunggah",
    "No file was uploaded" : "Tidak ada berkas yang diunggah",
    "Missing a temporary folder" : "Folder sementara tidak ada",
    "Could not write file to disk" : "Tidak dapat menulis berkas ke diska",
    "A PHP extension stopped the file upload" : "Ekstensi PHP menghentikan proses unggah berkas",
    "No file uploaded or file size exceeds maximum of %s" : "Gagal unggah berkas atau ukuran melampaui batas maksimum %s",
    "File could not be loaded. Please check your internet connection." : "Berkas tidak dapat dimuat. Periksa koneksi internet Anda.",
    "Edit guest name" : "Edit nama tamu",
    "Guest" : "Tamu",
    "Save guest name" : "Simpan nama tamu",
    "guest" : "pengunjung",
    "Saving …" : "Menyimpan ...",
    "Saved" : "Disimpan",
    "Formatting help" : "Bantuan pemformatan",
    "Keyboard shortcuts" : "Pintasan keyboard",
    "Select file or folder to link to" : "Pilih berkas atau folder untuk ditautkan",
    "Translate" : "Terjemahkan",
    "to" : "untuk",
    "Replace" : "Timpa",
    "Source code" : "Kode sumber",
    "Unsupported image type" : "Tipe gambar tidak bisa diterima",
    "Undo" : "Undo",
    "Info" : "Info",
    "Warning" : "Peringatan",
    "Control" : "Kendali",
    "Add notes, lists or links …" : "Tambahkan catatan, daftar, atau tautan...",
    "Edit" : "Sunting"
},
"nplurals=1; plural=0;");

==> nextcloud-31.0.4-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/text/l10n/id.js <==
OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "Berkas terunggah",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Berkas terunggah melampau parameter upload_max_filesize pada php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Berkas yang diunggah melampaui direktif MAX_FILE_SIZE yang ditentukan dalam formulir HTML.",
    "The file was only partially uploaded" : "Berkas hanya sebagian terunggah",
    "No file was uploaded" : "Tidak ada berkas yang diunggah",
    "Missing a temporary folder" : "Folder sementara tidak ada",
    "Could not write file to disk" : "Tidak dapat menulis berkas ke diska",
    "A PHP extension stopped the file upload" : "Ekstensi PHP menghentikan proses unggah berkas",
    "No file uploaded or file size exceeds maximum of %s" : "Gagal unggah berkas atau ukuran melampaui batas maksimum %s",
    "New text file" : "Berkas teks baru",
    "File not found" : "Berkas tidak ditemukan",
    "Text" : "Teks",
    "Translate" : "Terjemahkan",
    "Reload" : "Muat ulang",
    "Edit guest name" : "Edit nama tamu",
    "Guest" : "Tamu",
    "Save guest name" : "Simpan nama tamu",
    "guest" : "pengunjung",
    "Saving …" : "Menyimpan ...",
    "Saved" : "Disimpan",
    "Unsaved changes" : "Perubahan belum disimpan",
    "Keyboard shortcuts" : "Pintasan keyboard",
    "Link" : "Tautan",
    "Undo" : "Undo",
    "Redo" : "Ulang lagi",
    "Cancel" : "Batal",
    "URL" : "URL",
    "Formatting help" : "Bantuan pemformatan",
    "to" : "untuk",
    "Replace" : "Timpa",
    "Upload" : "Unggah",
    "Edit" : "Sunting",
    "Source code" : "Kode sumber",
    "Both" : "Keduanya",
    "Done" : "Selesai",
    "Lists" : "Daftar",
    "Details" : "Detail",
    "Formatting" : "Pemformatan",
    "Select file or folder to link to" : "Pilih berkas atau folder untuk ditautkan",
    "Info" : "Info",
    "Success" : "Berhasil",
    "Warning" : "Peringatan",
    "Control" : "Kendali",
    "Add notes, lists or links …" : "Tambahkan catatan, daftar, atau tautan..."
},
"nplurals=1; plural=0;");
